@@ -2,7 +2,7 @@ use std::fmt::{self, Write};
 
 use owo_colors::{OwoColorize, Style};
 
-use crate::chain::Chain;
+use crate::diagnostic_chain::DiagnosticChain;
 use crate::handlers::theme::*;
 use crate::protocol::{Diagnostic, Severity};
 use crate::{LabeledSpan, MietteError, ReportHandler, SourceCode, SourceSpan, SpanContents};
@@ -199,8 +199,12 @@ impl GraphicalReportHandler {
 
         writeln!(f, "{}", textwrap::fill(&diagnostic.to_string(), opts))?;
 
-        if let Some(cause) = diagnostic.source() {
-            let mut cause_iter = Chain::new(cause).peekable();
+        if let Some(mut cause_iter) = diagnostic
+            .diagnostic_source()
+            .map(DiagnosticChain::from_diagnostic)
+            .or_else(|| diagnostic.source().map(DiagnosticChain::from_stderror))
+            .map(|it| it.peekable())
+        {
             while let Some(error) = cause_iter.next() {
                 let is_last = cause_iter.peek().is_none();
                 let char = if !is_last {
@@ -255,7 +259,11 @@ impl GraphicalReportHandler {
         if let Some(related) = diagnostic.related() {
             writeln!(f)?;
             for rel in related {
-                write!(f, "Error: ")?;
+                match diagnostic.severity() {
+                    Some(Severity::Error) | None => write!(f, "Error: ")?,
+                    Some(Severity::Warning) => write!(f, "Warning: ")?,
+                    Some(Severity::Advice) => write!(f, "Advice: ")?,
+                };
                 self.render_header(f, rel)?;
                 writeln!(f)?;
                 self.render_causes(f, rel)?;
@@ -772,12 +780,13 @@ impl Line {
     }
 
     fn span_applies(&self, span: &FancySpan) -> bool {
+        let spanlen = if span.len() == 0 { 1 } else { span.len() };
         // Span starts in this line
         (span.offset() >= self.offset && span.offset() < self.offset + self.length)
         // Span passes through this line
-        || (span.offset() < self.offset && span.offset() + span.len() > self.offset + self.length) //todo
+        || (span.offset() < self.offset && span.offset() + spanlen > self.offset + self.length) //todo
         // Span ends on this line
-        || (span.offset() + span.len() > self.offset && span.offset() + span.len() <= self.offset + self.length)
+        || (span.offset() + spanlen > self.offset && span.offset() + spanlen <= self.offset + self.length)
     }
 
     // A 'flyby' is a multi-line span that technically covers this line, but
