@@ -59,6 +59,11 @@ pub trait Diagnostic: std::error::Error {
     fn related<'a>(&'a self) -> Option<Box<dyn Iterator<Item = &'a dyn Diagnostic> + 'a>> {
         None
     }
+
+    /// The cause of the error.
+    fn diagnostic_source(&self) -> Option<&dyn Diagnostic> {
+        None
+    }
 }
 
 impl std::error::Error for Box<dyn Diagnostic> {
@@ -406,6 +411,24 @@ impl From<std::ops::Range<ByteOffset>> for SourceSpan {
     }
 }
 
+impl From<SourceOffset> for SourceSpan {
+    fn from(offset: SourceOffset) -> Self {
+        Self {
+            offset,
+            length: 0.into(),
+        }
+    }
+}
+
+impl From<ByteOffset> for SourceSpan {
+    fn from(offset: ByteOffset) -> Self {
+        Self {
+            offset: offset.into(),
+            length: 0.into(),
+        }
+    }
+}
+
 /**
 "Raw" type for the byte offset from the beginning of a [`SourceCode`].
 */
